/* Any copyright is dedicated to the Public Domain.
   http://creativecommons.org/publicdomain/zero/1.0/ */

"use strict";

/**
 * Test that we don't run debuggee code when getting symbol names.
 */

const URL = "foo.js";

add_task(
  threadFrontTest(async ({ threadFront, debuggee }) => {
    await testSymbols(threadFront, debuggee);
  })
);

async function testSymbols(threadFront, debuggee) {
  const evalCode = () => {
    /* eslint-disable */
    Cu.evalInSandbox(
      "(" + function () {
        Symbol.prototype.toString = () => {
          throw new Error("lololol");
        };
        var sym = Symbol("le troll");
        debugger;
      } + "())",
      debuggee,
      "1.8",
      URL,
      1
    );
    /* eslint-enable */
  };

  const packet = await executeOnNextTickAndWaitForPause(evalCode, threadFront);
  const { sym } = packet.frame.environment.bindings.variables;

  equal(sym.value.type, "symbol");
  equal(sym.value.name, "le troll");
}
